@@ -91,14 +91,14 @@ BT.1886.EOTF <- function( gamma=2.4, Lb=0, Lw=1 )
     {
     if( length(gamma)!=1  ||  gamma <= 0 )
         {
-        log.string( ERROR, "gamma=%g is invalid.", gamma )
+        log_string( ERROR, "gamma=%g is invalid.", gamma )
         return(NULL)
         }
         
     ok  = length(Lb)==1  &&  length(Lw)==1  &&  (0 <= Lb)  &&  (Lb < Lw)
     if( ! ok )
         {
-        log.string( ERROR, "Lb=%g  and/or  Lw=%g are invalid.", Lb, Lw )
+        log_string( ERROR, "Lb=%g  and/or  Lw=%g are invalid.", Lb, Lw )
         return(NULL)
         }
             
@@ -177,7 +177,7 @@ EOTFfromString  <-  function( id )
     ok  = is.character(id)  &&  length(id)==1
     if( ! ok )
         {
-        log.string( ERROR, "id='%s' is invalid.", as.character(id)[1] )
+        log_string( ERROR, "id='%s' is invalid.", as.character(id)[1] )
         return(NULL)
         }          
     
@@ -186,7 +186,7 @@ EOTFfromString  <-  function( id )
     idx = pmatch( tolower(id), tolower(id.full) )
     if( is.na(idx) )
         {
-        log.string( ERROR, "id='%s' is invalid; it may match more than one EOTF.", id )
+        log_string( ERROR, "id='%s' is invalid; it may match more than one EOTF.", id )
         return(NULL)
         }          
 
@@ -208,7 +208,7 @@ power.OETF  <-  function( gamma )
     ok  = is.numeric(gamma)  &&  length(gamma)==1  &&  0<gamma
     if( ! ok )
         {
-        log.string( ERROR, "gamma = '%s' is invalid.", as.character(gamma) )
+        log_string( ERROR, "gamma = '%s' is invalid.", as.character(gamma) )
         return(NULL)
         }   
         
@@ -229,7 +229,7 @@ power.EOTF  <-  function( gamma )
     ok  = is.numeric(gamma)  &&  length(gamma)==1  &&  0<gamma
     if( ! ok )
         {
-        log.string( ERROR, "gamma = '%s' is invalid.", as.character(gamma) )
+        log_string( ERROR, "gamma = '%s' is invalid.", as.character(gamma) )
         return(NULL)
         }   
         
@@ -251,7 +251,7 @@ power.OOTF  <-  function( gamma )       #   end-to-end OOTF
     ok  = is.numeric(gamma)  &&  length(gamma)==1  &&  0<gamma
     if( ! ok )
         {
-        log.string( ERROR, "gamma = '%s' is invalid.", as.character(gamma) )
+        log_string( ERROR, "gamma = '%s' is invalid.", as.character(gamma) )
         return(NULL)
         }   
         
@@ -279,7 +279,7 @@ affine.TF  <-  function( y0, y1 )
     ok  = is.numeric(y0)  &&  is.numeric(y1)  &&  length(y0)==1  &&  length(y1)==1  &&  y0!=y1  # &&  Ymin<Ymax
     if( ! ok )
         {
-        log.string( ERROR, "y0='%s' or y1='%s' is invalid, or they are equal.", 
+        log_string( ERROR, "y0='%s' or y1='%s' is invalid, or they are equal.", 
                                 as.character(y0)[1], as.character(y1)[1] )
         return(NULL)
         }   
@@ -307,7 +307,7 @@ validTF  <-  function( TF )
     ok  = all( TF(endpoint) == endpoint )
     if( ! ok )
         {
-        log.string( ERROR, "Transfer Function does not map 0->0 and 1->1." )
+        log_string( ERROR, "Transfer Function does not map 0->0 and 1->1." )
         return(FALSE)
         }    
     
@@ -316,7 +316,7 @@ validTF  <-  function( TF )
     ok  = all( 0 < diff(y) )
     if( ! ok )
         {
-        log.string( ERROR, "Transfer Function is not strictly monotone." )
+        log_string( ERROR, "Transfer Function is not strictly monotone." )
         return(FALSE)
         }        
         
@@ -326,7 +326,7 @@ validTF  <-  function( TF )
     ok  = all( dim(y) == dim(x) )
     if( ! ok )
         {
-        log.string( ERROR, "Transfer Function does not preserve dimensions." )
+        log_string( ERROR, "Transfer Function does not preserve dimensions." )
         return(FALSE)
         }        
 
@@ -345,7 +345,7 @@ validTF_pair  <-  function( TF1, TF2, digits=5 )
     delta   = max( abs( x - x.back ) )  #; print(delta)
     if( tol <= delta )
         {
-        log.string( ERROR, "Transfer Function pair are not inverses, to %d digits.  TF1(TF2(x))", digits )
+        log_string( ERROR, "Transfer Function pair are not inverses, to %d digits.  TF1(TF2(x))", digits )
         return(FALSE)
         }       
     
@@ -353,7 +353,7 @@ validTF_pair  <-  function( TF1, TF2, digits=5 )
     delta   = max( abs( x - x.back ) )
     if( tol <= delta )
         {
-        log.string( ERROR, "Transfer Function pair are not inverses, to %d digits.  TF2(TF1(x))", digits )
+        log_string( ERROR, "Transfer Function pair are not inverses, to %d digits.  TF2(TF1(x))", digits )
         return(FALSE)
         }       
 
@@ -378,7 +378,7 @@ fittedGammaL1 <- function( TF )
         
     res = optimize( myfun, lower=0.5*gamma, upper=2*gamma ) #; print( str(res) )
         
-    #   log.string( INFO, "LM polished gamma=%g to %g in %d iterations.", gamma, res$par, res$niter )
+    #   log_string( INFO, "LM polished gamma=%g to %g in %d iterations.", gamma, res$par, res$niter )
 
     return( res$minimum )
     }
