@@ -115,7 +115,7 @@ SignalRGBfromLinearRGB <- function( RGB, space='sRGB', which='scene', TF=NULL, m
             TF  = (theSpace$EOTF)^-1    # backwards from display to signal
         else 
             {
-            log.string( ERROR, "For RGB space='%s', the EOTF is not invertible.", space )
+            log_string( ERROR, "For RGB space='%s', the EOTF is not invertible.", space )
             return(NULL)
             }    
         }
@@ -131,7 +131,7 @@ SignalRGBfromLinearRGB <- function( RGB, space='sRGB', which='scene', TF=NULL, m
         
     if( ! is.TransferFunction(TF) )        
         {
-        log.string( ERROR, "argument TF is invalid."  )
+        log_string( ERROR, "argument TF is invalid."  )
         return(NULL)
         }        
         
@@ -234,7 +234,7 @@ LinearRGBfromSignalRGB <- function( RGB, space='sRGB', which='scene', TF=NULL, m
     ok  = is.numeric(maxSignal)  &&  length(maxSignal)==1  &&  0<maxSignal
     if( ! ok )
         {
-        log.string( ERROR, "maxSignal='%s' is not a positive number.", as.character(maxSignal) )
+        log_string( ERROR, "maxSignal='%s' is not a positive number.", as.character(maxSignal) )
         return(NULL)
         }    
         
@@ -260,7 +260,7 @@ LinearRGBfromSignalRGB <- function( RGB, space='sRGB', which='scene', TF=NULL, m
             TF  = (theSpace$OETF)^-1    # backwards to scene
         else 
             {
-            log.string( ERROR, "For RGB space='%s', the OETF is not invertible.", space )
+            log_string( ERROR, "For RGB space='%s', the OETF is not invertible.", space )
             return(NULL)
             }    
         }
@@ -276,7 +276,7 @@ LinearRGBfromSignalRGB <- function( RGB, space='sRGB', which='scene', TF=NULL, m
 
     if( ! is.TransferFunction( TF ) )
         {
-        log.string( ERROR, "argument TF is invalid."  )
+        log_string( ERROR, "argument TF is invalid."  )
         return(NULL)
         }        
 
@@ -315,7 +315,7 @@ endIndex <- function( which )
     w   = pmatch( tolower(which), c('scene','display') )
     if( is.na(w) )
         {
-        log.string( ERROR, "which='%s' is invalid.", which )
+        log_string( ERROR, "which='%s' is invalid.", which )
         return(NA_integer_)
         }
 
